---
name: Bug report
about: Create a report to help us improve
title: BUG
labels: bug
assignees: FedeClaudi

---
**Issues with jupyter notebooks**
We have received [several issues related to Jupyter notebooks](https://github.com/brainglobe/brainrender/issues?q=is%3Aissue+is%3Aopen+label%3A%22Jupyter+Notebooks%22).
If your issue is specific to running brainrender in a notebook, please check if any of the previously addressed issues is helpful, look at the [documentation on using notebooks](https://docs.brainrender.info/usage/using-notebooks) and try running the [notebooks workflow example](https://github.com/brainglobe/brainrender/blob/master/examples/notebook_workflow.ipynb) **before** opening a new issue. 

If you are not sure if your issue is specific to jupyter notebooks, try running your code in a python script (i.e. with a `.py` file) and see if you get the same error, or any error at all. If you don't then the problem is restricted to notebooks.


**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
First tell us which version of `brainrender` and `vedo` you're using and something about your system (e.g. OS etc). 

Then tell us the steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.
